@@ -1,13 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mpv" "0.2.0"
+(define-package "mpv" "20241121.2308"
   "Control mpv for easy note-taking."
-  '((cl-lib "0.5")
-    (emacs  "25.1")
-    (json   "1.3")
-    (org    "8.0"))
+  '((emacs "25.1"))
   :url "https://github.com/kljohann/mpv.el"
-  :commit "4fd8baa508dbc1a6b42b4e40292c0dbb0f19c9b9"
-  :revdesc "4fd8baa508db"
+  :commit "62cb8825d525d7c9475dd93d62ba84d419bc4832"
+  :revdesc "62cb8825d525"
   :keywords '("tools" "multimedia")
   :authors '(("Johann Klähn" . "johann@jklaehn.de"))
   :maintainers '(("Johann Klähn" . "johann@jklaehn.de")))
